@@ -2,7 +2,6 @@
 # coding: utf-8
 require 'nokogiri'
 require 'httpclient'
-#require 'totoridipjp'
 require 'json'
 
 module Plugin::PhotoSupport
@@ -179,18 +178,6 @@ Plugin.create :photo_support do
     open('http://d250g2.com/d250g2.jpg')
   end
 
-  # totori.dip.jp
-  defimageopener('totori.dip.jp', %r#\Ahttp://totori\.dip\.jp/?\Z#) do |display_url|
-#    iwashi = Totoridipjp.イワシがいっぱいだあ…ちょっとだけもらっていこうかな
-#    if iwashi.url
-#      open(iwashi.url) end
-    connection = HTTPClient.new
-    page = connection.get_content(display_url)
-    next nil if page.empty?
-    doc = Nokogiri::HTML(page)
-    open(doc.css('meta[property="og:image"]').first.attribute('content'))
-  end
-
   # 600eur.gochiusa.net
   defimageopener('600eur.gochiusa.net', %r#\Ahttp://600eur\.gochiusa\.net/?\Z#) do |display_url|
     img = Plugin::PhotoSupport.d250g2(display_url)
@@ -304,4 +291,9 @@ Plugin.create :photo_support do
     img = Plugin::PhotoSupport.インスタ映え(display_url)
     open(img) if img
   end
+  # pixiv new
+  defimageopener('pixiv', %r<https?://(?:www\.)?pixiv\.net/artworks/\d+$>) do |display_url|
+    img = Plugin::PhotoSupport.インスタ映え(display_url)
+    open(img) if img
+  end
 end
